@@ -17,6 +17,7 @@ class Table:
     _pk_field: str = None
     _data_source_name: str = None
     _hash_field: str = None
+    _debug: bool = False
 
     def __init__(
         self,
@@ -28,6 +29,7 @@ class Table:
         pk_field: str = None,
         data_source_name: str = None,
         hash_field: str = None,
+        debug: bool = False,
     ):
         conf = models.Config(
             endpoint=endpoint,
@@ -40,6 +42,7 @@ class Table:
         self._pk_field = pk_field
         self._data_source_name = data_source_name
         self._hash_field = hash_field
+        self._debug = debug
 
     def insert(self, dict_list: List[Dict[str, str]]):
         document_array = []
@@ -47,8 +50,9 @@ class Table:
         for field_map in dict_list:
             if self._pk_field not in field_map:
                 field_map[self._pk_field] = id_generator.get_id()
-            if self._hash_field is not None and len(self._hash_field) > 0:
-                md5.update(field_map.get(self._hash_field))
+            if self._hash_field is not None and len(self._hash_field) > 0 and self._hash_field in field_map\
+                    and len(field_map.get(self._hash_field)) > 0:
+                md5.update(field_map.get(self._hash_field).encode("utf8"))
                 hash_value = md5.hexdigest()
                 hash_field = self._hash_field + "_hash"
                 field_map[hash_field] = hash_value
@@ -60,6 +64,8 @@ class Table:
         request = models.PushDocumentsRequestModel()
         request.body = document_array
         response = self._client.push_documents(self._data_source_name, self._pk_field, request)
+        if self._debug:
+            print("request:{}, response:{}".format(document_array, response))
         return response.body
 
     def query(self, query_map: Dict[str, List[str]], page: int, query_num: int):
@@ -90,6 +96,8 @@ class Table:
         ha_query_request = models.SearchRequestModel(query=search_query)
 
         search_response = self._client.search(ha_query_request)
+        if self._debug:
+            print("request:{}, response:{}".format(ha_query_request, search_response))
         return search_response.body
 
     def search(self, vec: List[float], filter_expr: str = None, city_id: int = 0, topn: int = 30):
@@ -125,7 +133,8 @@ class Table:
         ha_query_request = models.SearchRequestModel(query=search_query)
 
         search_response = self._client.search(ha_query_request)
-
+        if self._debug:
+            print("request:{}, response:{}".format(ha_query_request, search_response))
         return search_response.body
 
     def delete(self, pk_value: List[int]):
@@ -144,11 +153,13 @@ class Table:
         request = models.PushDocumentsRequestModel()
         request.body = document_array
         response = self._client.push_documents(self._data_source_name, self._pk_field, request)
+        if self._debug:
+            print("request:{}, response:{}".format(request, response))
         return response.body
 
     def update_annotation(self, raw_field_value: str):
         md5 = hashlib.md5()
-        md5.update(raw_field_value)
+        md5.update(raw_field_value.encode("utf8"))
         hash_value = md5.hexdigest()
         hash_field_name = self._hash_field + "_hash"
         query_map = {
@@ -160,6 +171,12 @@ class Table:
         for item in rs_dict['result']['items']:
             if item['fields'][self._hash_field] == raw_field_value:
                 id_list.append(item['fields'][self._pk_field])
+        if len(id_list) == 0:
+            resp = {
+                "status": "failed",
+                "code": 1
+            }
+            return json.dumps(resp)
         document_array = []
         for pk_id in id_list:
             update_fields = {
@@ -168,10 +185,12 @@ class Table:
             }
             update_document = {
                 'fields': update_fields,
-                'cmd': 'update',
+                'cmd': 'update_field',
             }
             document_array.append(update_document)
         request = models.PushDocumentsRequestModel()
         request.body = document_array
         response = self._client.push_documents(self._data_source_name, self._pk_field, request)
+        if self._debug:
+            print("request:{}, response:{}".format(request, response))
         return response.body
